{% if widget.is_initial %}
<p class="file-upload">
    {% if widget.value %}
        {{ widget.value.width }} × {{ widget.value.height }}

        <img src="{{ widget.value.url }}"
         style=" display: block; max-width: 400px; max-height: 400px;"/>
    {% endif %}
<!--
    {{ widget.initial_text }}:
    <a href="{{ widget.value.url }}">{{ widget.value }}</a>
-->
    {% if not widget.required %}
    <span class="clearable-file-input">
        <input type="checkbox"
            name="{{ widget.checkbox_name }}"
            id="{{ widget.checkbox_id }}" />
        <label for="{{ widget.checkbox_id }}">
            {{ widget.clear_checkbox_label }}
        </label>
    </span>{% endif %}<br />
    {{ widget.input_text }}:{% endif %}
    <input type="{{ widget.type }}"
        name="{{ widget.name }}"
        {% include "django/forms/widgets/attrs.html" %} />
{% if widget.is_initial %}</p>{% endif %}
